@@ -90,7 +90,7 @@ class Strategy:
         signal = signal.copy()
 
         # 三列模式 转换 pivot table
-        if isinstance(signal.index[0], int):
+        if isinstance(signal.index[0], (int, np.int64)):
             signal.columns = [c.lower() for c in signal.columns]
             columns = {'date', 'stockid', 'weight'}
             assert columns.issubset(signal), f"signal must contain {columns}"
@@ -183,16 +183,16 @@ class Strategy:
     @staticmethod
     def _get_relative_ret(strategy, benchmark, trades_dt):
         """[summary]
-        
+
         Arguments:
             strategy {[pd.Series]} -- [nav]
             benchmark {[pd.Series]} -- [nav]
             trades_dt {[series]} -- [description]
-        
+
         Raises:
             ValueError: [description]
             ValueError: [description]
-        
+
         Returns:
             [type] -- [description]
         """
@@ -289,7 +289,7 @@ class Strategy:
         Returns:
             [type] -- [description]
         """
-        t = signal.diff().abs().sum(axis=1).sum() / delta * 252
+        t = signal.fillna(0).diff().abs().sum(axis=1).sum() / delta * 252
         return t
 
     def _hedge_ret(self, long_ret, short_ret):
@@ -325,10 +325,10 @@ class Strategy:
 
     def run(self, stats=True, relative=False):
         """[summary]
-        
+
         Keyword Arguments:
             stats {bool} -- [是否增加其他统计结果] (default: {True})
-        
+
         Raises:
             ValueError: [description]
             ValueError: [description]
@@ -370,8 +370,8 @@ class Strategy:
             ret_future.to_frame('future'),
             ret_hedge.to_frame('hedge')
         ],
-                            axis=1,
-                            sort=False)
+            axis=1,
+            sort=False)
         if self.benchmark:
             benchmark = self._close.reindex([self.benchmark], axis=1)
             if benchmark.empty:
@@ -381,7 +381,8 @@ class Strategy:
                 ret_all[self.benchmark].dropna().iloc[0]
         else:
             self.benchmark = 'benchmark'
-            ret_all[self.benchmark] = np.exp(np.log1p(self.fixed_rate) / 252) - 1
+            ret_all[self.benchmark] = np.exp(
+                np.log1p(self.fixed_rate) / 252) - 1
             ret_all.iloc[0, -1] = 0.0
             ret_all[self.benchmark] = (1 + ret_all[self.benchmark]).cumprod()
 
